import React from 'react';
import { Meta } from '@storybook/react';
import LineChart, { LineChartProps } from '.';

const Component: Meta<typeof LineChart> = {
  title: 'Visual charts/Charts/LineChart',
  component: LineChart,
  decorators: [(story) => <div style={{ width: '100%', height: '100vh' }}>{story()}</div>],
};

export default Component;

export const Default = {
  args: {
    data: [
      // First line
      [
        { x: 1, y: 2 },
        { x: 2, y: 6 },
        { x: 3, y: 2 },
        { x: 5, y: 9 },
        { x: 8, y: 2 },
        { x: 9, y: 9 },
      ],
      // Second line
      [
        { x: 1, y: 4 },
        { x: 3, y: 3 },
        { x: 4, y: 8 },
        { x: 6, y: 5 },
        { x: 7, y: 7 },
        { x: 9, y: 3 },
      ],
    ],
    xAxisLabel: 'X Axis Label',
    yAxisLabel: 'Y Axis Label',
    showMarks: true,
    curveInterpolation: ['smooth', 'linear', 'step', 'natural'],
    isArea: true,
  },
};

export const CategoricalData = {
  args: {
    data: [
      // First line
      [
        { x: 'A', y: 2 },
        { x: 'B', y: 6 },
        { x: 'C', y: 2 },
        { x: 'D', y: 9 },
        { x: 'E', y: 2 },
        { x: 'F', y: 9 },
      ],
      // Second line
      [
        { x: 'A', y: 4 },
        { x: 'B', y: 3 },
        { x: 'C', y: 8 },
        { x: 'D', y: 5 },
        { x: 'E', y: 7 },
        { x: 'F', y: 3 },
      ],
    ],
    xAxisLabel: 'Categories',
    yAxisLabel: 'Values',
    showMarks: true,
    curveInterpolation: 'linear',
    isArea: false,
  },
};

export const DateTimeData = {
  args: {
    data: [
      // First line
      [
        { x: new Date(2020, 0, 1), y: 2 },
        { x: new Date(2020, 1, 1), y: 6 },
        { x: new Date(2020, 2, 1), y: 2 },
        { x: new Date(2020, 3, 1), y: 9 },
        { x: new Date(2020, 4, 1), y: 2 },
        { x: new Date(2020, 5, 1), y: 9 },
      ],
      // Second line
      [
        { x: new Date(2020, 0, 1), y: 4 },
        { x: new Date(2020, 2, 1), y: 3 },
        { x: new Date(2020, 3, 1), y: 8 },
        { x: new Date(2020, 4, 1), y: 5 },
        { x: new Date(2020, 6, 1), y: 7 },
        { x: new Date(2020, 8, 1), y: 3 },
      ],
    ],
    xAxisLabel: 'Date',
    yAxisLabel: 'Values',
    showMarks: true,
    curveInterpolation: 'natural',
    isArea: false,
  },
};
